; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Super Motions |--------------------------------------------------------
[Command]
Name = "ice_explosive_kunai_throw"
Command = $D,DB,B,b
Time = 20

[Command]
Name = "hyouton_no_jutsu_-_hyouton_kanban"
Command = $D,DF,F,a
Time = 20

[Command]
Name = "hyouton_no_jutsu_-_hyouro_no_jutsu"
Command = $D,DB,B,a
Time = 20

[Command]
Name = "hyouton_no_jutsu_-_hyouton_jizou"
Command = $D,DF,F,c
Time = 20

[Command]
Name = "hyouton_rasengan"
Command = $D,DB,B,DB,D,DF,F,c
Time = 30

[Command]
Name = "hyouton_rasengan"
Command = $D,B,D,F,c
Time = 30

[Command]
Name = "heyringan"
Command = $D,DB,B,c
Time = 30

[Command]
Name = "heyringan"
Command = $D,B,c
Time = 30

;-| Special Motions |------------------------------------------------------

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================

;---------------------------------------------------------------------------
; Air Dash Forward
[State -1, Air Dash Fwd]
Type = ChangeState
Value = 80
Trigger1 = Power >= 50
Trigger1 = Command = "FF"
Trigger1 = StateType = A
Trigger1 = Ctrl

;---------------------------------------------------------------------------
; Air Dash Backward
[State -1, Air Dash Back]
Type = ChangeState
Value = 85
Trigger1 = Power >= 50
Trigger1 = Command = "BB"
Trigger1 = StateType = A
Trigger1 = Ctrl

;---------------------------------------------------------------------------
; Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Combo (Hit 01)
[State -1, Combo (Hit 01)]
type = ChangeState
value = 200
triggerall = command = "a"
triggerall = Command != "b"
triggerall = command != "holddown"
triggerall = Command != "holdup"
TriggerAll = Command != "holdfwd"
TriggerAll = Command != "holdback"
triggerall = StateNo != 100
triggerall = StateNo != 105
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Combo (Hit 02)
[State -1, Combo (Hit 02)]
type = ChangeState
value = 210
triggerall = command = "a"
triggerall = Command != "b"
triggerall = command != "holddown"
triggerall = Command != "holdup"
TriggerAll = Command != "holdfwd"
TriggerAll = Command != "holdback"
triggerall = StateNo != 100
triggerall = StateNo != 105
trigger1 = StateType = S
trigger1 = StateNo = 200 && MoveContact

;---------------------------------------------------------------------------
; Combo (Hit 03)
[State -1, Combo (Hit 03)]
type = ChangeState
value = 220
triggerall = command = "a"
triggerall = Command != "b"
triggerall = command != "holddown"
triggerall = Command != "holdup"
TriggerAll = Command != "holdfwd"
TriggerAll = Command != "holdback"
triggerall = StateNo != 100
triggerall = StateNo != 105
trigger1 = statetype = S
trigger1 = StateNo = 210 && MoveContact

;---------------------------------------------------------------------------
; Up Attack
[State -1, Up Attack]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = Command != "b"
triggerall = StateNo != 100
triggerall = StateNo != 105
TriggerAll = Command != "holdfwd"
trigger1 = Command = "holdup"
trigger1 = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = StateNo = 300
trigger2 = MoveContact

;---------------------------------------------------------------------------
; Run Attack
[State -1, Run Attack]
type = ChangeState
value = 240
triggerall = command = "a"
triggerall = Command != "b"
triggerall = command != "holddown"
triggerall = Command != "holdup"
trigger1 = statetype = S
trigger1 = StateNo = 100
trigger2 = StateType = S
trigger2 = StateNo = 105

;---------------------------------------------------------------------------
; Tomino Cl Power
[State -1, Tomino Cl Power]
type = ChangeState
value = 250
triggerall = command = "a"
triggerall = Command = "b"
triggerall = command != "holddown"
triggerall = command != "holdup"
triggerall = Power < 3000
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Teleport
[State -1, Teleport]
Type = ChangeState
Value = 260
TriggerAll = Command = "s"
TriggerAll = Power >= 50
Trigger1 = ctrl

;---------------------------------------------------------------------------
; Wall Jump
[State -1, Wall Jump]
Type = ChangeState
Value = 270
TriggerAll = Command = "holdback"
TriggerAll = Anim != 42
TriggerAll = Anim != 45
Trigger1 = StateType = A
Trigger1 = BackEdgeBodyDist = 0
Trigger1 = Pos Y <= -60
Trigger1 = Ctrl

; Front
[State -1, Wall Jump]
Type = ChangeState
Value = 272
TriggerAll = Command = "holdfwd"
TriggerAll = Anim != 41
TriggerAll = Anim != 43
TriggerAll = Anim != 44
TriggerAll = Anim != 46
Trigger1 = StateType = A
Trigger1 = FrontEdgeBodyDist = 0
Trigger1 = Pos Y <= -60
Trigger1 = Ctrl

;---------------------------------------------------------------------------
; Stand Weapon Throw
[State -1, Stand Weapon Throw]
Type = ChangeState
Value = 280
Triggerall = Command = "b"
Triggerall = Command != "a"
Triggerall = Command != "holddown"
Triggerall = Command != "holdup"
TriggerAll = Command != "holdfwd"
TriggerAll = Command != "holdback"
TriggerAll = NumHelper(281) <= 4
Trigger1 = StateType = S
Trigger1 = Ctrl

;---------------------------------------------------------------------------
; Crouching Attack
[State -1, Crouching Attack]
type = ChangeState
value = 300
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouch Weapon Throw
[State -1, Crouch Weapon Throw]
Type = ChangeState
Value = 310
Triggerall = Command = "b"
Triggerall = Command != "a"
Triggerall = Command = "holddown"
Triggerall = Command != "holdup"
Triggerall = NumHelper(281) <= 4
Trigger1 = StateType = C
Trigger1 = Ctrl

;---------------------------------------------------------------------------
; Jump Attack
[State -1, Jump Attack]
type = ChangeState
value = 320
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Air Weapon Throw
[State -1, Air Weapon Throw]
Type = ChangeState
Value = 330
Triggerall = Command = "b"
Triggerall = Command != "a"
Triggerall = NumHelper(281) <= 4
Trigger1 = StateType = A
Trigger1 = Ctrl

;---------------------------------------------------------------------------
; Ice Weapon Throw
[State -1, Ice Weapon Throw]
Type = ChangeState
Value = 340
Triggerall = Command = "b"
Triggerall = Command != "a"
Triggerall = Command != "holddown"
Triggerall = Command != "holdup"
TriggerAll = Command = "holdfwd"
TriggerAll = Power >= 500
Trigger1 = StateType = S
Trigger1 = Ctrl

;---------------------------------------------------------------------------
; Ice Explosive Kunai Throw
[State -1, Ice Explosive Kunai Throw]
Type = ChangeState
Value = 350
TriggerAll = Command = "ice_explosive_kunai_throw"
TriggerAll = NumHelper(351) = 0
Trigger1 = StateType = S
Trigger1 = Ctrl

;---------------------------------------------------------------------------
; Active Ice Explosive Kunai Throw
[State -1, Active Ice Explosive Kunai Throw]
Type = ChangeState
Value = 356
TriggerAll = Command = "ice_explosive_kunai_throw"
TriggerAll = Var(4) = 1
TriggerAll = Power >= 1000
Trigger1 = StateType = S
Trigger1 = Ctrl

;---------------------------------------------------------------------------
; Hyouton no Jutsu - Hyouton Kanban
[State -1, Hyouton no Jutsu - Hyouton Kanban]
type = ChangeState
value = 360
triggerall = command = "hyouton_no_jutsu_-_hyouton_kanban"
TriggerAll = Power >= 1000
TriggerAll = Command != "b"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Hyouton no Jutsu - Hyoro no Jutsu
[State -1, Hyouton no Jutsu - Hyoro no Jutsu]
type = ChangeState
value = 370
triggerall = command = "hyouton_no_jutsu_-_hyouro_no_jutsu"
TriggerAll = Power >= 1000
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Hyouton no Jutsu - Hyouton Jizou
[State -1, Hyouton no Jutsu - Hyouton Jizou]
type = ChangeState
value = IfElse((Power >= 2000),390,380)
triggerall = command = "hyouton_no_jutsu_-_hyouton_jizou"
TriggerAll = Command != "hyouton_rasengan"
TriggerAll = Power >= 1000
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Air Hyouton no Jutsu - Hyouton Jizou
[State -1, Air Hyouton no Jutsu - Hyouton Jizou]
type = ChangeState
value = 400
triggerall = command = "hyouton_no_jutsu_-_hyouton_jizou"
TriggerAll = Power >= 1000
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Hyouton Rasengan
[State -1, Hyouton Rasengan]
Type = ChangeState
Value = 450
TriggerAll = Command = "hyouton_rasengan"
Trigger1 = Power >= 3000
Trigger1 = StateType = S
Trigger1 = Ctrl
Trigger2 = Var(23) = 1
Trigger2 = StateType = S
Trigger2 = Ctrl
Trigger2 = Power >= 2300

;---------------------------------------------------------------------------
;Heyringan
[State -1, Heyringan]
Type = ChangeState
Value = 500
TriggerAll = Var(23) = 0
TriggerAll = Command = "heyringan"
Trigger1 = StateType = S
Trigger1 = Ctrl
